===========================
UserAndGroupSelectionWidget
===========================

-------
Purpose
-------

UserAndGroupSelectionWidget is a widget to search and select users
and/or groups from a huge base of users. It uses a modernized, fast code-base
and is tested with hundreds of groups and thousands of users.

It is configurable to select only groups, only users, both or only user of a 
distinct group.

Widgets for both Archetypes and z3c.form are available.

------------
Dependencies
------------

* bda.cache

The 3.0beta1 version now additionally depends on:

* lxml
* plone.dexterity

It's possible to make these dependencies optional, and this should perhaps be done
before the final 3.0 release.


--------------------
Author and Copyright
--------------------

Thanks to panjunyong (panjy at zopen.cn) for his work on ATMemberSelectWidget,
which was the base for idea (and some parts of the code) of this Widget.

Authors: 

- Robert Niederreiter <rnix@squarewave.at>,
- Jens Klein <jens@bluedynamics.com>,  
- Johannes Raggam <johannes@bluedynamics.com>,

Copyright (C) 2007-2010 BlueDynamics Alliance, Klein & Partner KG, Austria

This code was made for BKS Chur Project: 
Communication-Platform/Intranet/e-learning.
